@@ -8,7 +8,11 @@ from .available_reservation import AvailableReservation
 from .characteristic import Characteristic
 from .check_client_application_request import CheckClientApplicationRequest
 from .check_client_application_response import CheckClientApplicationResponse
+from .checksum_description import ChecksumDescription
+from .checksum_description_type import ChecksumDescriptionType
 from .client_application import ClientApplication
+from .client_applications_download_link import ClientApplicationsDownloadLink
+from .create_endpoint_parameters import CreateEndpointParameters
 from .create_engagement_request import CreateEngagementRequest
 from .create_reservation_request import CreateReservationRequest
 from .dictionary import Dictionary
