@@ -2,6 +2,7 @@ from typing import Any, Callable, Dict, Optional
 
 import attr
 
+from ..types import UNSET
 from ..util.serialization import is_not_none
 
 
@@ -17,8 +18,12 @@ class AuthResetPasswordRequest:
         old_password = self.old_password
 
         dct = {
-            "newPassword": new_password,
-            "oldPassword": old_password,
+            k: v
+            for k, v in {
+                "newPassword": new_password,
+                "oldPassword": old_password,
+            }.items()
+            if v != UNSET
         }
         if pick_by_predicate is not None:
             dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
