@@ -2,6 +2,7 @@ from typing import Any, Callable, Dict, Optional
 
 import attr
 
+from ..types import UNSET
 from ..util.serialization import is_not_none
 
 
@@ -17,8 +18,12 @@ class CheckClientApplicationRequest:
         version = self.version
 
         dct = {
-            "name": name,
-            "version": version,
+            k: v
+            for k, v in {
+                "name": name,
+                "version": version,
+            }.items()
+            if v != UNSET
         }
         if pick_by_predicate is not None:
             dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
