@@ -2,6 +2,7 @@ from typing import Any, Callable, Dict, Optional
 
 import attr
 
+from ..types import UNSET
 from ..util.serialization import is_not_none
 
 
@@ -19,9 +20,13 @@ class CheckClientApplicationResponse:
         message = self.message
 
         dct = {
-            "isLatestVersion": is_latest_version,
-            "isUpdateRequired": is_update_required,
-            "message": message,
+            k: v
+            for k, v in {
+                "isLatestVersion": is_latest_version,
+                "isUpdateRequired": is_update_required,
+                "message": message,
+            }.items()
+            if v != UNSET
         }
         if pick_by_predicate is not None:
             dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
