@@ -2,6 +2,7 @@ from typing import Any, Callable, Dict, Optional
 
 import attr
 
+from ..types import UNSET
 from ..util.serialization import is_not_none
 
 
@@ -23,11 +24,15 @@ class Endpoint:
         quantum_processor_id = self.quantum_processor_id
 
         dct = {
-            "address": address,
-            "healthy": healthy,
-            "id": id,
-            "mock": mock,
-            "quantumProcessorId": quantum_processor_id,
+            k: v
+            for k, v in {
+                "address": address,
+                "healthy": healthy,
+                "id": id,
+                "mock": mock,
+                "quantumProcessorId": quantum_processor_id,
+            }.items()
+            if v != UNSET
         }
         if pick_by_predicate is not None:
             dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
