@@ -24,8 +24,12 @@ class ListEndpointsResponse:
         next_page_token = self.next_page_token
 
         dct = {
-            "endpoints": endpoints,
-            "nextPageToken": next_page_token,
+            k: v
+            for k, v in {
+                "endpoints": endpoints,
+                "nextPageToken": next_page_token,
+            }.items()
+            if v != UNSET
         }
         if pick_by_predicate is not None:
             dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
