@@ -3,6 +3,7 @@ from typing import Any, Callable, Dict, List, Optional
 import attr
 
 from ..models.reservation import Reservation
+from ..types import UNSET
 from ..util.serialization import is_not_none
 
 
@@ -22,8 +23,12 @@ class ListReservationsResponse:
             reservations.append(reservations_item)
 
         dct = {
-            "nextPageToken": next_page_token,
-            "reservations": reservations,
+            k: v
+            for k, v in {
+                "nextPageToken": next_page_token,
+                "reservations": reservations,
+            }.items()
+            if v != UNSET
         }
         if pick_by_predicate is not None:
             dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
