@@ -2,6 +2,7 @@ from typing import Any, Callable, Dict, Optional
 
 import attr
 
+from ..types import UNSET
 from ..util.serialization import is_not_none
 
 
@@ -19,7 +20,11 @@ class Node:
         node_id = self.node_id
 
         dct = {
-            "node_id": node_id,
+            k: v
+            for k, v in {
+                "node_id": node_id,
+            }.items()
+            if v != UNSET
         }
         if pick_by_predicate is not None:
             dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
