@@ -20,9 +20,13 @@ class TranslateNativeQuilToEncryptedBinaryRequest:
         settings_timestamp = self.settings_timestamp
 
         dct = {
-            "numShots": num_shots,
-            "quil": quil,
-            "settingsTimestamp": settings_timestamp,
+            k: v
+            for k, v in {
+                "numShots": num_shots,
+                "quil": quil,
+                "settingsTimestamp": settings_timestamp,
+            }.items()
+            if v != UNSET
         }
         if pick_by_predicate is not None:
             dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
