@@ -24,9 +24,13 @@ class ValidationError:
             path = self.path
 
         dct = {
-            "in": in_,
-            "message": message,
-            "path": path,
+            k: v
+            for k, v in {
+                "in": in_,
+                "message": message,
+                "path": path,
+            }.items()
+            if v != UNSET
         }
         if pick_by_predicate is not None:
             dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
